[**开始使用**](./getting-started.md) > **如何安装** > **WebUI** _(当前)_

---

### 通过 Webui 使用 PDFMathTranslate

#### 如何打开 WebUI 页面：

有多种方法可以打开 WebUI 界面。如果您使用的是**Windows**系统，请参考[这篇文章](./INSTALLATION_winexe.md);

1. 已安装 Python（3.10 <= 版本 <= 3.13）

2. 安装我们的包：

3. 在浏览器中开始使用：

    ```bash
    pdf2zh_next --gui
    ```

4. 如果浏览器没有自动启动，请访问

    ```bash
    http://localhost:7860/
    ```

    将 PDF 文件拖入窗口并点击`Translate`。

<!-- <img src="./images/gui.gif" width="500"/> -->
<img src='./../images/gui.gif' width="500"/>

### 环境变量

您可以通过环境变量设置源语言和目标语言：

- `PDF2ZH_LANG_FROM`: 设置源语言。默认为"English"。
- `PDF2ZH_LANG_TO`: 设置目标语言。默认为"Simplified Chinese"。

## 预览效果

<img src="./../images/before.png" width="500"/>
<img src="./../images/after.png" width="500"/>

## 维护说明

图形界面由 [Rongxin](https://github.com/reycn) 维护

<div align="right"> 
<h6><small>本页面的部分内容由 GPT 翻译，可能包含错误。</small></h6>